@@ -4,7 +4,7 @@
 // Author:      Stefan Neis
 // Modified by:
 // Created:     22.09.2003
-// RCS-ID:      $Id: apptrait.h,v 1.5 2006/10/29 19:19:58 SN Exp $
+// RCS-ID:      $Id: apptrait.h 53707 2008-05-22 21:19:43Z SN $
 // Copyright:   (c) 2003 Stefan Neis <Stefan.Neis@t-online.de>
 // Licence:     wxWindows licence
 ///////////////////////////////////////////////////////////////////////////////
@@ -41,6 +41,16 @@ public:
 #endif
 };
 
+#ifndef __WXPM__
+inline void wxGUIAppTraits::InitializeGui(unsigned long &WXUNUSED(ulHab))
+{
+}
+
+inline void wxGUIAppTraits::TerminateGui(unsigned long WXUNUSED(ulHab))
+{
+}
+#endif
+
 #endif // wxUSE_GUI
 
 #endif // _WX_OS2_APPTRAIT_H_
