@@ -4,7 +4,7 @@
 // Author:      Julian Smart
 // Modified by:
 // Created:     17/09/98
-// RCS-ID:      $Id: app.cpp 53607 2008-05-16 15:21:40Z SN $
+// RCS-ID:      $Id: app.cpp 61713 2009-08-20 00:01:55Z VZ $
 // Copyright:   (c) Julian Smart
 // Licence:     wxWindows licence
 /////////////////////////////////////////////////////////////////////////////
@@ -105,7 +105,7 @@ bool wxApp::Initialize(int& argC, wxChar **argV)
     {
         if (wxStrcmp( argV[i], _T("-display") ) == 0)
         {
-            if (i < (argC - 1))
+            if (i < (argCOrig - 1))
             {
                 argV[i++] = NULL;
 
@@ -117,7 +117,7 @@ bool wxApp::Initialize(int& argC, wxChar **argV)
         }
         else if (wxStrcmp( argV[i], _T("-geometry") ) == 0)
         {
-            if (i < (argC - 1))
+            if (i < (argCOrig - 1))
             {
                 argV[i++] = NULL;
 
@@ -154,12 +154,12 @@ bool wxApp::Initialize(int& argC, wxChar **argV)
 
     if ( argC != argCOrig )
     {
-        // remove the argumens we consumed
+        // remove the arguments we consumed
         for ( int i = 0; i < argC; i++ )
         {
             while ( !argV[i] )
             {
-                memmove(argV + i, argV + i + 1, argCOrig - i);
+                memmove(argV + i, argV + i + 1, (argCOrig - i)*sizeof(wxChar *));
             }
         }
     }
